from setuptools import setup

setup(name='probabis',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['probabs'],
      author = 'Alvaro Montoya',
      author_email = 'ajaltamiranomontoya@gmail.com',
      zip_safe=False)
